Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
.tox/py313/lib/python3.13/site-packages/pylint_sort_functions/__init__.py | 4 | 0 | 2 | 100%
.tox/py313/lib/python3.13/site-packages/pylint_sort_functions/auto_fix.py | 176 | 0 | 18 | 100%
.tox/py313/lib/python3.13/site-packages/pylint_sort_functions/checker.py | 50 | 0 | 3 | 100%
.tox/py313/lib/python3.13/site-packages/pylint_sort_functions/cli.py | 49 | 0 | 16 | 100%
.tox/py313/lib/python3.13/site-packages/pylint_sort_functions/messages.py | 1 | 0 | 0 | 100%
.tox/py313/lib/python3.13/site-packages/pylint_sort_functions/utils.py | 199 | 0 | 2 | 100%
Total | 479 | 0 | 41 | 100%

No items found using the specified filter.